"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyEnabledSonarQubeArguments = void 0;
const path = require("path");
const fs = require("fs");
const tl = require("azure-pipelines-task-lib/task");
// Apply arguments to enable SonarQube analysis.
// Returns the changed toolRunner. Has no effect if SonarQube is not enabled.
function applyEnabledSonarQubeArguments(gradleRun) {
    const specifyPluginVersion = tl.getInput('sqGradlePluginVersionChoice') === 'specify';
    if (specifyPluginVersion) {
        // #1: Inject custom script to the Gradle build, triggering a SonarQube run
        // Add a custom initialisation script to the Gradle run that will apply the SonarQube plugin and task
        // Set the SonarQube Gradle plugin version in the script
        const pluginVersion = getSonarQubeGradlePluginVersion();
        let initScriptPath = path.join(__dirname, 'sonar.gradle');
        let scriptContents = fs.readFileSync(initScriptPath, 'utf8');
        scriptContents = scriptContents.replace('SONARQUBE_GRADLE_PLUGIN_VERSION', pluginVersion);
        tl.writeFile(initScriptPath, scriptContents);
        // Specify that the build should run the init script
        gradleRun.arg(['-I', initScriptPath]);
    }
    gradleRun.arg(['sonarqube']);
    return gradleRun;
}
exports.applyEnabledSonarQubeArguments = applyEnabledSonarQubeArguments;
function getSonarQubeGradlePluginVersion() {
    let pluginVersion = '2.6.1';
    let userSpecifiedVersion = tl.getInput('sqGradlePluginVersion');
    if (userSpecifiedVersion) {
        pluginVersion = userSpecifiedVersion.trim();
    }
    return pluginVersion;
}
